#
# spec file for package kicad-doc
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# No texlive-collection-langjapanese in 42.1 or 13.2
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
%bcond_without japanese
%else
%bcond_with japanese
%endif
%bcond_without italian
#eeschema_pdf_en fails to build in obs but builds local.
%bcond_with pdf

Name:           kicad-doc
Version:        4.0.5
Release:        1.4
Summary:        Documentation and tutorials for KiCad
License:        SUSE-OldFSFDocLicense
Group:          Documentation/Other
Url:            http://kicad-pcb.org
Source:         https://github.com/KiCad/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source2:        https://raw.githubusercontent.com/KiCad/kicad-source-mirror/master/license_for_documentation.txt
Patch0:         verbose-a2x-debug.patch
BuildRequires:  asciidoc >= 8.6.9
BuildRequires:  cmake
BuildRequires:  dblatex >= 0.3.4
BuildRequires:  fdupes
BuildRequires:  gettext >= 0.18
BuildRequires:  git
BuildRequires:  libxslt-tools
BuildRequires:  po4a >= 0.45
BuildRequires:  source-highlight
BuildRequires:  texlive-collection-langeuropean
BuildRequires:  texlive-collection-langfrench
BuildRequires:  texlive-collection-langgerman
BuildRequires:  texlive-collection-langitalian
%if %{with japanese}
BuildRequires:  texlive-collection-langjapanese
BuildRequires:  vlgothic-fonts
%endif
BuildRequires:  texlive-collection-langcyrillic
BuildRequires:  texlive-collection-langpolish
BuildRequires:  texlive-collection-langspanish
BuildRequires:  texlive-collection-latexrecommended
BuildRequires:  texlive-collection-xetex
BuildRequires:  texlive-euenc
BuildRequires:  texlive-gnu-freefont-fonts
BuildRequires:  texlive-xetexref
BuildRequires:  perl(Unicode::LineBreak)
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       kicad

%description
Kicad is an open source software for the creation of electronic
schematic diagrams and printed circuit board artwork.
This is the documentation package for KiCad. It contains documentation
and tutorials.

%package        en
Summary:        English documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(kicad-doc:en)
Requires:       kicad-doc = %{version}

%description    en
This package contains English documentation and tutorials for KiCad

%package        fr
Summary:        French documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(kicad-doc:fr)
Requires:       kicad-doc = %{version}

%description    fr
This package contains French documentation and tutorials for KiCad

%if %{with italian}
%package        it
Summary:        Italian documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(kicad-doc:it)
Requires:       kicad-doc = %{version}

%description    it
This package contains Italian documentation and tutorials for KiCad
%endif

%if %{with japanese}
%package        ja
Summary:        Japanese documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(kicad-doc:ja)
Requires:       kicad-doc = %{version}

%description    ja
This package contains Japanese documentation and tutorials for KiCad
%endif

%package        nl
Summary:        Netherlandian documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(kicad-doc:nl)
Requires:       kicad-doc = %{version}

%description    nl
This package contains Netherlandian documentation and tutorials for KiCad

%package        pl
Summary:        Polish documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(kicad-doc:pl)
Requires:       kicad-doc = %{version}

%description    pl
This package contains Polish documentation and tutorials for KiCad

%package        ca
Summary:        Catalan documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(kicad-doc:ca)
Requires:       kicad-doc = %{version}

%description    ca
This package contains Catalan documentation and tutorials for KiCad

%package        de
Summary:        German documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(kicad-doc:de)
Requires:       kicad-doc = %{version}

%description    de
This package contains German documentation and tutorials for KiCad

%package        es
Summary:        Spanish documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(kicad-doc:es)
Requires:       kicad-doc = %{version}

%description    es
This package contains Spanish documentation and tutorials for KiCad

%package        ru
Summary:        Russian documentation and tutorials for KiCad
Group:          Documentation/Other
Provides:       locale(kicad-doc:ru)
Requires:       kicad-doc = %{version}

%description    ru
This package contains Russian documentation and tutorials for KiCad

%prep
%setup -q
cp %{SOURCE2} .

# Fix documentation path
sed -i "s|share/doc/kicad|share/doc/packages/kicad|" CMakeModules/KiCadDocumentation.cmake
%patch0

# FIXME
%if %{without japanese}
# Delete japanese translation due to build problems
find src/ -name 'addendum.ja' -type f -delete -print
find src/ -name 'ja.po' -type f -delete -print
%endif
#Problems with italian too
%if %{without italian}
find src/ -name 'addendum.it' -type f -delete -print
find src/ -name 'it.po' -type f -delete -print
%endif

%build
%if %{with pdf}
%cmake
%else
%cmake -DBUILD_FORMATS:STRING=html
%endif

make all %{?_smp_mflags}
#make cvpcb
#make gerbview
#make getting_started_in_kicad
#make idf_exporter
#make kicad
#make pcbnew
#make plugins
#make pl_editor
#make gui_translation_howto
%if 1 == 0
make eeschema_pdf_ru
make eeschema_pdf_fr
make eeschema_pdf_es
make eeschema_pdf_de
make eeschema_pdf_pl
make eeschema_pdf_en
%endif

%install
%cmake_install

install -Dm644 license_for_documentation.txt %{buildroot}%{_datadir}/doc/packages/kicad/

%fdupes -s %{buildroot}%{_datadir}/doc/packages/kicad/help/en
%fdupes -s %{buildroot}%{_datadir}/doc/packages/kicad/help/fr
%fdupes -s %{buildroot}%{_datadir}/doc/packages/kicad/help/nl
%fdupes -s %{buildroot}%{_datadir}/doc/packages/kicad/help/pl
%fdupes -s %{buildroot}%{_datadir}/doc/packages/kicad/help/ca
%fdupes -s %{buildroot}%{_datadir}/doc/packages/kicad/help/de
%fdupes -s %{buildroot}%{_datadir}/doc/packages/kicad/help/es
%fdupes -s %{buildroot}%{_datadir}/doc/packages/kicad/help/ru
%if %{with italian}
%fdupes -s %{buildroot}%{_datadir}/doc/packages/kicad/help/it
%endif
%if %{with japanese}
%fdupes -s %{buildroot}%{_datadir}/doc/packages/kicad/help/ja
%endif

%files
%defattr(-,root,root)
%dir %{_datadir}/doc/packages/kicad/
%dir %{_datadir}/doc/packages/kicad/help/
%{_datadir}/doc/packages/kicad/license_for_documentation.txt

%files en
%defattr(-,root,root)
%{_datadir}/doc/packages/kicad/help/en/

%files fr
%defattr(-,root,root)
%{_datadir}/doc/packages/kicad/help/fr/

%if %{with italian}
%files it
%defattr(-,root,root)
%{_datadir}/doc/packages/kicad/help/it/
%endif

%if %{with japanese}
%files ja
%defattr(-,root,root)
%{_datadir}/doc/packages/kicad/help/ja/
%endif

%files nl
%defattr(-,root,root)
%{_datadir}/doc/packages/kicad/help/nl/

%files pl
%defattr(-,root,root)
%{_datadir}/doc/packages/kicad/help/pl/

%files ca
%defattr(-,root,root)
%{_datadir}/doc/packages/kicad/help/ca/

%files de
%defattr(-,root,root)
%{_datadir}/doc/packages/kicad/help/de/

%files es
%defattr(-,root,root)
%{_datadir}/doc/packages/kicad/help/es/

%files ru
%defattr(-,root,root)
%{_datadir}/doc/packages/kicad/help/ru/

# There's clearly a changelog tag

%changelog
* Thu Jan 12 2017 davejplater@gmail.com
- Update to version 4.0.5
- Disabled problematic pdf builds, html is needed for kicad help.
- Enabled Japanese and 42.x Italian packages html builds ok.
* Mon Sep 12 2016 davejplater@gmail.com
- Update to version 4.0.4
- Added new packages for Catalan, Russian, Spanish and German.
- Added verbose-a2x-debug.patch for verbose a2x output.
* Mon Mar 21 2016 dmitry_r@opensuse.org
- Update to version 4.0.2
* Wed Dec  2 2015 dmitry_r@opensuse.org
- Update to version 4.0.0
* Fri Sep 25 2015 dmitry_r@opensuse.org
- Update to version 4.0.0~20150925
* Wed Jul 31 2013 dmitry_r@opensuse.org
- Update to version 20130728
* Tue Apr  9 2013 werner.ho@gmx.de
- update to version 20130409
* Fri Jan 25 2013 dmitry_r@opensuse.org
- Update to version 20130120
- Change license to SUSE-OldFSFDocLicense [bnc#796377]
* Fri Dec 28 2012 dmitry_r@opensuse.org
- spec file cleanup
* Fri May 27 2011 werner.ho@gmx.de
- new version 2011-04-29
* Tue Apr 13 2010 mhopf@novell.com
- Update to 2010-04-06-SVN2508
* Tue Dec 16 2008 werner.ho@gmx.de
- directory fix for openSUSE 11.1
* Sat Oct  4 2008 werner.ho@gmx.de
- new version 1.1
* Tue Mar 25 2008 werner.ho@gmx.de
- initial build of the kicad documentation package version 1.0
